@@ -21,6 +21,7 @@ uninstall (setup.py uninstall --record=INSTALLED_FILES), otherwise use
 the wrapper script in the root directory of the source tar.gz/zip
 
 """
+import functools
 from configparser import ConfigParser
 from distutils.command.install import install
 from distutils.util import change_root, get_platform
@@ -38,23 +39,32 @@ from time import strftime
 
 
 # # Borrowed from setuptools
-# def findall(dir=os.curdir):
-#     """Find all files under 'dir' and return the list of full filenames
-#     (relative to 'dir').
-#     """
-#     all_files = []
-#     for base, _dirs, files in os.walk(dir, followlinks=True):
-#         if base == os.curdir or base.startswith(os.curdir + os.sep):
-#             base = base[2:]
-#         if base:
-#             files = [os.path.join(base, f) for f in files]
-#         all_files.extend(list(filter(os.path.isfile, files)))
-#     return all_files
+def _find_all_simple(path):
+    """
+    Find all files under 'path'
+    """
+    results = (
+        os.path.join(base, file)
+        for base, dirs, files in os.walk(path, followlinks=True)
+        for file in files
+    )
+    return filter(os.path.isfile, results)
+
+
+def findall(dir=os.curdir):
+    """
+    Find all files under 'dir' and return the list of full filenames.
+    Unless dir is '.', return full filenames with dir prepended.
+    """
+    files = _find_all_simple(dir)
+    if dir == os.curdir:
+        make_rel = functools.partial(os.path.relpath, start=dir)
+        files = map(make_rel, files)
+    return list(files)
 
 
 import distutils.filelist
-
-# distutils.filelist.findall = findall  # Fix findall bug in distutils
+distutils.filelist.findall = findall  # Fix findall bug in distutils
 
 
 from DisplayCAL.defaultpaths import autostart, autostart_home
@@ -443,8 +453,6 @@ def setup():
     prefix = ""
     recordfile_name = None  # record installed files to this file
     sdist = "sdist" in sys.argv[1:]
-    setuptools = None
-    skip_instrument_conf_files = "--skip-instrument-configuration-files" in sys.argv[1:]
     skip_postinstall = "--skip-postinstall" in sys.argv[1:]
     use_distutils = not bdist_bbfreeze and not do_py2app
     use_setuptools = (
@@ -468,12 +476,13 @@ def setup():
         except ImportError:
             pass
         try:
+            import setuptools
             from setuptools import setup, Extension
 
-            setuptools = True
             print("using setuptools")
-            current_findall = distutils.filelist.findall
+            current_findall = setuptools.findall
         except ImportError:
+            use_setuptools = False
             pass
     else:
         if os.path.exists("use-setuptools"):
@@ -499,7 +508,7 @@ def setup():
 
         distutils.filelist.findall = findall
 
-    if not setuptools:
+    if not use_setuptools:
         from distutils.core import setup, Extension
 
         print("using distutils")
@@ -512,10 +521,13 @@ def setup():
         sys.argv = sys.argv[:i] + ["install"] + sys.argv[i + 1:]
         install.create_home_path = lambda self: None
 
-    if skip_instrument_conf_files:
+    if skip_instrument_conf_files := "--skip-instrument-configuration-files" in sys.argv[1:]:
         i = sys.argv.index("--skip-instrument-configuration-files")
         sys.argv = sys.argv[:i] + sys.argv[i + 1:]
 
+    if not is_rpm_build:
+        skip_instrument_conf_files = True
+
     if skip_postinstall:
         i = sys.argv.index("--skip-postinstall")
         sys.argv = sys.argv[:i] + sys.argv[i + 1:]
@@ -932,7 +944,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
     ext_modules = [RealDisplaySizeMM]
 
     requires = []
-    if not setuptools or sys.platform != "win32":
+    if not use_setuptools or sys.platform != "win32":
         # wxPython windows installer doesn't add egg-info entry, so
         # a dependency check from pkg_resources would always fail
         requires.append("wxPython (>= %s)" % ".".join(str(n) for n in wx_minversion))
@@ -952,14 +964,17 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
     elif sys.platform == "darwin":
         # On Mac OS X we only want the universal binaries
         packages.append(f"{name}.lib{bits}")
-    else:
-        # On Linux/Windows we want separate libraries
+    elif sys.platform == "win32":
+        # On Windows we want separate libraries
         packages.extend(
             [
                 f"{name}.lib{bits}",
                 f"{name}.lib{bits}.python{sys.version_info[0]}{sys.version_info[1]}",
             ]
         )
+    else:
+        # On Linux the libraries will be built on build step
+        pass
 
     attrs = {
         "author": author_ascii,
@@ -1005,7 +1020,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         "version": msiversion if "bdist_msi" in sys.argv[1:] else version,
     }
 
-    if setuptools:
+    if use_setuptools:
         attrs["entry_points"] = {
             "gui_scripts": [
                 "%s = %s.main:main%s"
@@ -1262,7 +1277,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
             attrs["options"]["py2exe"].update(
                 {"bundle_files": 3, "compressed": 0, "optimize": 0, "skip_archive": 1}
             )
-        if setuptools:
+        if use_setuptools:
             attrs["setup_requires"] = ["py2exe"]
         attrs["zipfile"] = os.path.join("lib", "library.zip")
 
@@ -1312,10 +1327,10 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         # site-packages (on Mac and Windows) and when we want to make them
         # absolute (Linux)
         linux = sys.platform not in ("darwin", "win32") and (
-            not cmd.root and setuptools
+            not cmd.root and use_setuptools
         )
         dar_win = (
-            sys.platform in ("darwin", "win32") and (cmd.root or not setuptools)
+            sys.platform in ("darwin", "win32") and (cmd.root or not use_setuptools)
         ) or bdist_win
         if (
             not do_uninstall
@@ -1364,7 +1379,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
             # logic to find them
             paths = safe_glob(os.path.join(cmd.install_scripts, name))
             if sys.platform == "win32":
-                if setuptools:
+                if use_setuptools:
                     paths += safe_glob(os.path.join(cmd.install_scripts, f"{name}.exe"))
                     paths += safe_glob(
                         os.path.join(cmd.install_scripts, f"{name}-script.py")
@@ -1543,8 +1558,8 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
                 attrs.get("package_dir", {}).get(pkg, pkg).split("/")
             )
             manifest_in.append("include " + os.path.join(pkgdir, "*.py"))
-            manifest_in.append("include " + os.path.join(pkgdir, "*.pyd"))
-            manifest_in.append("include " + os.path.join(pkgdir, "*.so"))
+            # manifest_in.append("include " + os.path.join(pkgdir, "*.pyd"))
+            # manifest_in.append("include " + os.path.join(pkgdir, "*.so"))
             for obj in attrs.get("package_data", {}).get(pkg, []):
                 manifest_in.append(
                     "include " + os.path.sep.join([pkgdir] + obj.split("/"))
@@ -1571,7 +1586,7 @@ setup(ext_modules=[Extension("{name}.lib{bits}.RealDisplaySizeMM", sources={sour
         manifest_in.append("include " + os.path.join("tests", "*"))
         manifest_in.append("recursive-include theme *")
         manifest_in.append("recursive-include util *.cmd *.py *.sh")
-        if sys.platform == "win32" and not setuptools:
+        if sys.platform == "win32" and not use_setuptools:
             # Only needed under Windows
             manifest_in.append("global-exclude .svn/*")
         manifest_in.append("global-exclude *~")
